/**
 * @author v_wangyan
 * @date 2012-11-05
 */ 
var skin = window.skin || {};
/**
 * 获取元素对象
 * @param  {string} element 元素id
 * @return {object}         返回元素对象
 */
skin.g = function(element) {
    return document.getElementById(element) || element;
},
/**
 * 转换JSON对象
 * @param  {string} jsonString json字符串
 * @return {object}            json对象
 */
skin.jsonDecode =function(jsonString) {
	return (new Function("return " + jsonString))();
},
/**
 * 显示dom
 * @param  {string} id dom的id
 * @return {void}    无
 */

skin.show = function(id) {
	skin.isShow(id, true);
},
/**
 * 隐藏dom
 * @param  {string} id dom的id
 * @return {void}    无
 */
skin.hide = function(id) {
    skin.isShow(id, false);
},
/**
 * 是否显示
 * @return {bool} 返回布尔值
 */
skin.isShow = function() {
    skin.g(id).style.display = flag ? 'block' : 'none';
},
/**
 * 添加样式
 * @param {string|object} element   目标元素
 * @param {string} className 样式名称
 */
skin.addClass = function(element, className) { 
	element = skin.g(element)||element;
    var classArray = className.split(/\s+/),
        result = element.className,
        classMatch = " " + result + " ",
        i = 0,
        l = classArray.length;

    for (; i < l; i++) {
         if ( classMatch.indexOf( " " + classArray[i] + " " ) < 0 ) {
             result += (result ? ' ' : '') + classArray[i];
         }
    }

    element.className = result;
},
/**
 * 移除样式
 * @param  {string|object} element   目标元素
 * @param  {string} className 样式名称
 * @return {void}           无
 */
skin.removeClass = function(element, className) { 
	element = skin.g(element)||element; 

    var oldClasses = element.className.split(/\s+/),
        newClasses = className.split(/\s+/),
        lenOld,
        lenDel = newClasses.length,
        j,
        i = 0;  
    for (; i < lenDel; ++i) {
        for(j = 0, lenOld = oldClasses.length; j < lenOld; ++j) {
            if (oldClasses[j] == newClasses[i]) {
            	oldClasses.splice(j, 1);
            	break;
            }
        }
    }
    element.className = oldClasses.join(' ');
},
/**
 * 设置字体
 * @param {int}   
 * @return void
 */
skin.setFontFamily = function (key) {   //设置字体:  0-宋体 ; 1-微软雅黑;
    key = key || '0';
    var obj = document.body;
    var font = '';
    if (key) {
        font = '"微软雅黑", "宋体", Arial, Verdana';
    } else {
        font = '"宋体", "微软雅黑", Arial, Verdana';
    }
    obj.style.fontFamily = font;
}
/**
 * 设置页面显示的字体(win7--雅黑字,其他为宋体)
 * @param 无
 * @return string
 */
skin.getSysver = function () {
    var key = 0;
    try {
        key = execOrder('sysver');
        if ('6.1' == key) {
            key = 1;
        }
    } catch (e) {   }   
    
    skin.setFontFamily(key); 
}
/**
 * 处理icon点击
 * @param  {event} e          事件
 * @param  {bool} rightClick 是否为右键(点击)
 * @param  {number} key        iconid
 * @return {void}            无
 */
skin.execMouseDown = function (e, rightClick, key) {
    //取消冒泡事件
    e.stopPropagation(); 
    
    var order = rightClick ? 'mouseRDown' : 'mouseLDown';
    try {
        window.external.SyncRequest(order, key);
    } catch (e) {}  
},
/**
 * 处理右键点击
 * @param  {string} id elementid
 * @return {void}    无
 */
skin.rightButton = function (id) {
    if (event.button == 2) {
       skin.execMouseDown(event, true, id);
    }
},
/**
 * 执行命令
 * @param {string} 命令名称
 * @param {string} 值
 * @return string | void
 */
skin.execOrder = function (order, key) {
    var info = '';
    try { 
        key = (key.length == 0 ? '0' : key); 
        info = window.external.SyncRequest(order, key);
    } catch (e) {       
    } 
    return info;
},
/**
 * 执行客户端命令,获取参数
 * @param  {string} order 命令名称
 * @param  {string} param 参数
 * @return {void|object}       无|-
 */
skin.execSync = function (order, param) {
    try {
        if (window.external.SyncRequest) {
            return window.external.SyncRequest(order, param);
        } 
    } catch (e) {
        return '';
    }
    return '';
},
//获取RD数据status,null 时返回当前状态
/**
 * 设置icon状态
 * @param  {string} id  icon的id
 * @param  {string} key 命令
 * @return {void}     无
 */
skin.getExecStatus = function (id, key) {  
    if (typeof skin.g(id) == 'string') {
        return;
    }
    var statu = skin.execSync('getButtonState', key) || skin.g(id).getAttribute('statu'); 
    return statu;
},
/**
 * 初始输入法状态  
 * 参数:0 (中英文切换) 返回值: 0 英文 1 中文;
 * 参数:1 (全半角切换) 返回值: 0 半角 1 全角; 
 * 参数:2 (中英文标点) 返回值: 0 英文标点 1 中文标点;
 * 参数:3 (软键盘)
 * 参数:4 (登录)            返回值: 0 未登录 1 已登录
 * 参数:5 (配置)
 */
skin.setIMEStatus = function () { 
    setButtonState('0', skin.getExecStatus('language', '0'));    
    setButtonState('1', skin.getExecStatus('characters', '1'));  
    setButtonState('2', skin.getExecStatus('punctuation', '2')); 
},
/**
 * 绑定输入法icon点击/hover等事件
 * @return {void} 无
 */
skin.bindEvent = function () {
    var icons = skin.g('iconEvent').getElementsByTagName('img');
    for (var i = 0, len = icons.length; i < len; i++) {        
        icons[i].onclick = function () { 
            skin.execMouseDown(event, false, this.getAttribute('key'));
        }
        icons[i].onmouseup = function () { 
            skin.rightButton(this.getAttribute('key'));
        }
        icons[i].onmouseover = function () { 
            skin.execOrder('mouseOver', this.getAttribute('key'));
            var link = this.src;
                link = link.replace("_normal", '_hover');
                this.src = link;
        }
        icons[i].onmouseout = function () { 
            skin.execOrder('mouseOver', 'null');
            var link = this.src;
                link = link.replace("_hover", '_normal');
                this.src = link;
        }
    }
    document.onclick  =function () {
        skin.execMouseDown(event, false, 'null');    
    }
    
    document.onmouseup =function () {  
        skin.rightButton('null'); 
    }
},
skin.EventUtil = {
    addHandler: function(element,type,handler){
        if(element.addEventListener){
            element.addEventListener(type,handler,false)
        } else if(element.attachEvent){
            element.attachEvent("on"+type,handler);
        } 
        else{
            element["on"+type] = handler;
        }
    },
    removeHandler: function(element,type,handler){
        if(element.removeEventlistener){
            element.removeEventlistener(type,handler);
        } else if(element.detachEvent){
            element.detachEvent("on"+type,handler)
        } else{
            element['on'+type] = null;
        }

    },
    getEvent: function(event){
        return event ? event : window.event;
    },
    getTarget:function(event){
        return event.target || event.srcElement;

    },
    preventDefault:function(){
        if(event.preventDefault){
            event.preventDefault();
        } else{
            event.returnValue = false;
        }
    },
    stopPropagation:function(){
        if(event.stopPropagation){
            event.stopPropagation();
        } else{
            event.cancelBubble = true;
        }
    }

}
// 供客户端调用
function setButtonState(key, statu) { 
    var status = config.buttonstatus;
    var id = '';
    key = key || '0';
    id = status[key].id;
    if (typeof skin.g(id) == 'string') {
        return;
    }
    statu =  statu || (skin.g(id).getAttribute('statu') == '0' ? '1' : '0');     
    skin.g(id).src = 'images/icons/' + status[key][statu];
    skin.g(id).setAttribute ('statu', statu);        
}
function musicControl(){
    var obj = skin.g('music');
    skin.EventUtil.addHandler(obj,'click',handler); 
}
function handler(e){
    var  ev = skin.EventUtil.getEvent(e);
    var  tar = skin.EventUtil.getTarget(ev);
    var  id = tar.getAttribute('tag');
    switch (id){
        case 'play': skin.g('song').play();
                     skin.g('play').setAttribute('tag','stop');
                     skin.addClass(skin.g('play'),'stop')
                     break;
        case 'stop':skin.g('song').pause();
                     skin.g('play').setAttribute('tag','play');
                     skin.removeClass(skin.g('play'),'stop')
                     break;
        default:
    }
    
}

